@@ -1,5 +1,6 @@
 """Produces reporting to help interpret analysis and campaigns."""
 import logging
+from typing import Dict
 
 import matplotlib.pyplot as plt  # type: ignore
 import pandas as pd
@@ -8,7 +9,7 @@ import seaborn as sns
 from pricer import config as cfg, io
 
 logger = logging.getLogger(__name__)
-sns.set(rc={"figure.figsize": (3, 3)})
+sns.set(rc={"figure.figsize": (6, 6)})
 
 
 def have_in_bag() -> str:
@@ -19,8 +20,6 @@ def have_in_bag() -> str:
     sell_policy = sell_policy[
         sell_policy["sell_estimated_profit"] > sell_policy["profit_feasible"]
     ]
-
-    print(sell_policy["sell_estimated_profit"])
     return sell_policy[["sell_estimated_profit"]].astype(int).to_html()
 
 
@@ -32,13 +31,11 @@ def make_missing() -> str:
         (make_policy["user_make_pass"] == 0) & (make_policy["make_actual"] > 0)
     ]["make_actual"]
     make_me.name = "Automake"
-    print(make_me)
 
     make_main = make_policy[
         (make_policy["user_make_pass"] == 1) & (make_policy["make_ideal"] > 0)
     ]["make_ideal"]
     make_main.name = "Make on main"
-    print(make_main)
 
     make_should = make_policy[
         (
@@ -48,7 +45,6 @@ def make_missing() -> str:
         )
     ]["make_ideal"]
     make_should.name = "Missing mats"
-    print(make_should)
 
     making_html = pd.DataFrame(index=pd.concat([make_me, make_main, make_should]).index)
     making_html = (
@@ -153,6 +149,41 @@ def profit_per_item() -> str:
     return item_profits.to_html()
 
 
+def inventory_valuation() -> str:
+    """Profits per item as HTML."""
+    inventory_valuation = io.reader("reporting", "inventory_valuation", "parquet")
+    inventory_valuation = (
+        (inventory_valuation["inv_total_all"] / 10000)
+        .round(0)
+        .astype(int)
+        .sort_values(ascending=False)
+    )
+    inventory_valuation.name = "inventory_valuation"
+    inventory_valuation = pd.DataFrame(inventory_valuation)
+
+    return inventory_valuation.to_html()
+
+
+def grand_total() -> Dict[str, int]:
+    """Returns total inventory and money value."""
+    ark_monies = io.reader("cleaned", "ark_monies", "parquet")
+    inventory_valuation = io.reader("reporting", "inventory_valuation", "parquet")
+
+    inventory_value_total = (
+        (inventory_valuation["inv_total_all"].sum() / 10000).round(0).astype(int)
+    )
+    money_total = (ark_monies["monies"].sum() / 10000).round(0).astype(int)
+
+    grand_total = inventory_value_total + money_total
+
+    total_holdings = {
+        "Inventory": inventory_value_total,
+        "Money": money_total,
+        "Grand Total": grand_total,
+    }
+    return total_holdings
+
+
 def draw_profit_charts() -> None:
     """Create charts of alltime and individual item profits."""
     profits = io.reader("reporting", "profits", "parquet")
